@@ -1,12 +1,15 @@
 package Net::DNS::RR::DNAME;
 #
-# $Id: DNAME.pm 219 2005-03-03 14:18:10Z olaf $
+# $Id: DNAME.pm 388 2005-06-22 10:06:05Z olaf $
 #
 use strict;
+BEGIN { 
+    eval { require bytes; }
+} 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 219 $)[1];
+$VERSION = (qw$LastChangedRevision: 388 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
