@@ -1,6 +1,6 @@
 package Net::DNS::Resolver::Win32;
 #
-# $Id: Win32.pm 208 2005-03-02 14:59:43Z olaf $
+# $Id: Win32.pm 514 2005-11-15 13:02:54Z olaf $
 #
 
 use strict;
@@ -9,7 +9,7 @@ use vars qw(@ISA $VERSION);
 use Net::DNS::Resolver::Base ();
 
 @ISA     = qw(Net::DNS::Resolver::Base);
-$VERSION = (qw$LastChangedRevision: 247 $)[1];
+$VERSION = (qw$LastChangedRevision: 514 $)[1];
 
 use Win32::Registry;
 
@@ -88,24 +88,31 @@ sub init {
 	my $interfaces;
 	$resobj->Open("Interfaces", $interfaces);
 	if ($interfaces) {
-		my @ifacelist;
-		$interfaces->GetKeys(\@ifacelist);
-		foreach my $iface (@ifacelist) {
-			my $regiface;
-			$interfaces->Open($iface, $regiface);
-			if ($regiface) {
-				my $ns;
-				my $type;
-				# NameServer overrides DhcpNameServer if both exist
-				$regiface->QueryValueEx("NameServer", $type, $ns);
-				$regiface->QueryValueEx("DhcpNameServer", $type, $ns) unless $ns;
-				$nameservers .= " $ns" if $ns;
-			}
+	    my @ifacelist;
+	    $interfaces->GetKeys(\@ifacelist);
+	    foreach my $iface (@ifacelist) {
+		my $regiface;
+		$interfaces->Open($iface, $regiface);
+		
+		if ($regiface) {
+		    my $ns;
+		    my $type;
+		    my $ip;
+		    my $ipdhcp;
+		    $regiface->QueryValueEx("IPAddress", $type, $ip);
+		    $regiface->QueryValueEx("DhcpIPAddress", $type, $ipdhcp);
+		    if (($ip && !($ip =~ /0\.0\.0\.0/)) || ($ipdhcp && !($ipdhcp =~ /0\.0
+\.0\.0/))) {
+			# NameServer overrides DhcpNameServer if both exist
+			$regiface->QueryValueEx("NameServer", $type, $ns);
+			$regiface->QueryValueEx("DhcpNameServer", $type, $ns) unless $ns;
+			$nameservers .= " $ns" if $ns;
+		    }
 		}
+	    }
 	}
-
 	if (!$nameservers) {
-		$nameservers = $nt4nameservers;
+	    $nameservers = $nt4nameservers;
 	}
 
 	if ($domain) {
