@@ -1,14 +1,17 @@
 package Net::DNS::Update;
 #
-# $Id: Update.pm 264 2005-04-06 09:16:15Z olaf $
+# $Id: Update.pm 517 2005-11-21 08:38:47Z olaf $
 #
 use strict;
+BEGIN { 
+    eval { require bytes; }
+} 
 use vars qw($VERSION @ISA);
 
 use Net::DNS;
 
 @ISA     = qw(Net::DNS::Packet);
-$VERSION = (qw$LastChangedRevision: 264 $)[1];
+$VERSION = (qw$LastChangedRevision: 517 $)[1];
 
 =head1 NAME
 
@@ -125,7 +128,7 @@ show only the creation of the update packet.
 
     my $update = Net::DNS::Update->new('example.com');
     $update->push(pre    => nxdomain('info.example.com'));
-    $update->push(update => rr_add('info.example.com TXT 'yabba dabba doo''));
+    $update->push(update => rr_add('info.example.com TXT "yabba dabba doo"'));
 
 =head2 Delete all A records for a name
 
